==> fnss-1.0.1.tgz: package/src/context.js <==
/**
 * Copyright (c) 2017 Chris Baker <mail.chris.baker@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

'use strict';

function getPropsLessChildren({ children, ...props }) {
  return props;
}

function isEqual(a, b) {
  if (a === b) {
    return true;
  }

  const keysA = Object.keys(a);
  const keysB = Object.keys(b);
  const count = keysA.length;

  if (keysB.length !== count) {
    return false;
  }

  for (let i = 0; i < count; i++) {
    const key = keysA[i];

    if (a[key] !== b[key]) {
      return false;
    }
  }

  return true;
}

export default class StyleSheetContext {
  constructor(props) {
    this.listeners = [];
    this.props = getPropsLessChildren(props);
  }

  publish(properties) {
    const props = getPropsLessChildren(properties);

    if (!isEqual(this.props, props)) {
      this.listeners.forEach(listener => listener(props));
      this.props = props;
    }
  }

  subscribe(listener) {
    this.listeners.push(listener);

    return {
      remove: this.unsubscribe.bind(this, listener)
    };
  }

  unsubscribe(listener) {
    this.listeners = this.listeners.filter(l => l !== listener);
  }
}

==> fnss-1.2.1.tgz: package/src/context.js <==
/**
 * Copyright (c) 2017 Chris Baker <mail.chris.baker@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

'use strict';

export default class StyleSheetContext {
  constructor(state) {
    this._state = state;
    this._listeners = [];
  }

  getState() {
    return this._state;
  }

  publish(state) {
    this._listeners.forEach(listener => listener(state));
    this._state = state;
  }

  subscribe(listener) {
    this._listeners.push(listener);

    return {
      remove: () => this.unsubscribe(listener)
    };
  }

  unsubscribe(listener) {
    this._listeners = this._listeners.filter(l => l !== listener);
  }
}
